==> v28.0.1rc1.tar.gz: nextcloud/apps/updatenotification/l10n/uk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Доступна {version}. Отримати докладну інформацію про те, як оновити версію.",
    "Channel updated" : "Канал оновлено",
    "Web updater is disabled" : "Програму веб-оновлення вимкнено",
    "Update notifications" : "Сповіщення про оновлення",
    "The update server could not be reached since %d days to check for new updates." : "Неможливо отримати доступ до сервера оновлень протягом останніх %d днів для перевірки на наявність нових версій.",
    "Please check the Nextcloud and server log files for errors." : "Перегляньте журнал помилок Nextcloud та сервера на наявність інформації про помилки.",
    "Update to %1$s is available." : "Доступне оновлення до %1$s.",
    "Update to {serverAndVersion} is available." : "Доступне оновлення до {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Доступна версія {app} %s.",
    "Update notification" : "Сповіщення про оновлення",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Відображає сповіщення про оновлення для Nextcloud і надає SSO для програми оновлення.",
    "Update" : "Оновлення",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Ваша версія більше не підтримується. Будь ласка, оновіться якнайшвидше до версії, на яку поширюється підтримка.",
    "Apps missing compatible version" : "Ці застосунки не мають версії, що підтримується",
    "View in store" : "Переглянути у крамниці застосунків",
    "Apps with compatible version" : "Застосунки з підтримуваною версією",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Будь ласка, зверніть увагу, що веб-оновлювач не рекомендується, якщо кількість користувачів перевищує 100! Натомість використовуйте засіб оновлення командного рядка!",
    "Open updater" : "Оновити",
    "Download now" : "Звантажити зараз",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Веб-оновлення вимкнено. Для оновлення, будь ласка, скористайтеся засобом оновлення з командного рядка або відповідним до вашого методу встановлення механізмом оновлення (наприклад, Docker pull).",
    "What's new?" : "Що нового?",
    "View changelog" : "Переглянути журнал змін",
    "The update check is not yet finished. Please refresh the page." : "Перевірку на нові версії не завершено. Будь ласка, перезавантажте сторінку.",
    "Your version is up to date." : "У вас актуальна версія",
    "A non-default update server is in use to be checked for updates:" : "Використовується нетиповий сервер оновлення для перевірки на оновлення:",
    "Update channel" : "Канал оновлень",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Зміна каналу оновлень також вплине на сторінку керування застосунками. Так, після перемикання на канал \"бета\", вам пропонуватимуться до встановлення оновлення застосунків бета-версій на сторінці керування застосунками.",
    "Current update channel:" : "Поточний канал оновлень:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Ви завжди зможете перейти на нову версію, проте не можна буде повернутися на стабільну версію.",
    "Notify members of the following groups about available updates:" : "Повідомляти учасників таких груп про доступні оновлення:",
    "No groups" : "Без груп",
    "Only notifications for app updates are available." : "Доступні лише сповіщення про оновлення програми.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Вибраний канал оновлення робить спеціальні сповіщення для сервера застарілими.",
    "The selected update channel does not support updates of the server." : "Вибраний канал оновлення не підтримує оновлення сервера.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна нова версія: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Зауважте, що після нового випуску оновлення з’являється лише після першого другорядного випуску або пізніше. Ми розгортаємо нові версії з часом для наших користувачів і іноді пропускаємо версію, коли виявляються проблеми. Дізнайтеся більше про оновлення та канали випусків на {link}",
    "Checked on {lastCheckedDate}" : "Перевірень {lastCheckedDate}",
    "Checking apps for compatible versions" : "Перевірка програм на наявність сумісних версій",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Будь ласка, переконайтеся, що ваш config.php не встановлює для <samp>appstoreenabled</samp> значення false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Неможливо з'єднатися із App Store або оновлення не надійшли взагалі. Шукайте оновлення вручну або переконайтеся, що ваш сервер має доступ до Інтернету та може з'єднатися із App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Усі</strong> програми мають сумісну версію для цієї версії Nextcloud.",
    "Enterprise" : "Для бізнесу",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Для корпоративного використання. Завжди надає останній рівень виправлення, але не оновлюється до наступного основного випуску негайно. Це оновлення відбувається після того, як Nextcloud GmbH виконає додаткову надійність і тестування для широкомасштабних і критично важливих розгортань. Цей канал доступний лише для клієнтів і надає пакет Nextcloud Enterprise.",
    "Stable" : "Стабільна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Остання стабільна версія. Він підходить для регулярного використання та завжди оновлюється до останньої основної версії.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Попередня версія лише для тестування нових функцій, а не для робочих середовищ.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> застосункок не сумісний з цією версією Nextcloud.","<strong>%n</strong> застосунки не сумісні з цією версією Nextcloud.","<strong>%n</strong> застосунків не сумісні з цією версією Nextcloud.","<strong>%n</strong> застосунків не сумісні з цією версією Nextcloud."],
    "Please use the command line updater to update." : "Для оновлення використовуйте програму оновлення командного рядка.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Ви можете змінити канал оновлення нижче, що також впливає на сторінку керування програмами. наприклад після переходу на бета-канал оновлення бета-версії програми будуть запропоновані вам на сторінці керування програмами.",
    "Update channel:" : "Канал оновлення:"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> v28.0.2rc3.tar.gz: nextcloud/apps/updatenotification/l10n/uk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Доступна {version}. Отримати докладну інформацію про те, як оновити версію.",
    "Channel updated" : "Канал оновлено",
    "Web updater is disabled" : "Оновлення через веб вимкнено",
    "Update notifications" : "Сповіщення про оновлення",
    "The update server could not be reached since %d days to check for new updates." : "Неможливо отримати доступ до сервера оновлень протягом останніх %d днів для перевірки на наявність нових версій.",
    "Please check the Nextcloud and server log files for errors." : "Перегляньте журнал помилок Nextcloud та сервера на наявність інформації про помилки.",
    "Update to %1$s is available." : "Доступне оновлення до %1$s.",
    "Update to {serverAndVersion} is available." : "Доступне оновлення до {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Доступна версія {app} %s.",
    "Update notification" : "Сповіщення про оновлення",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Відображає сповіщення про оновлення для Nextcloud і надає SSO для програми оновлення.",
    "Update" : "Оновлення",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Ваша версія більше не підтримується. Будь ласка, оновіться якнайшвидше до версії, на яку поширюється підтримка.",
    "Apps missing compatible version" : "Ці застосунки не мають версії, що підтримується",
    "View in store" : "Переглянути у крамниці застосунків",
    "Apps with compatible version" : "Застосунки з підтримуваною версією",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Будь ласка, зверніть увагу, що веб-оновлювач не рекомендується, якщо кількість користувачів перевищує 100! Натомість використовуйте засіб оновлення командного рядка!",
    "Open updater" : "Оновити",
    "Download now" : "Звантажити зараз",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Веб-оновлення вимкнено. Для оновлення, будь ласка, скористайтеся засобом оновлення з командного рядка або відповідним до вашого методу встановлення механізмом оновлення (наприклад, Docker pull).",
    "What's new?" : "Що нового?",
    "View changelog" : "Переглянути журнал змін",
    "The update check is not yet finished. Please refresh the page." : "Перевірку на нові версії не завершено. Будь ласка, перезавантажте сторінку.",
    "Your version is up to date." : "У вас актуальна версія",
    "A non-default update server is in use to be checked for updates:" : "Використовується нетиповий сервер оновлення для перевірки на оновлення:",
    "Update channel" : "Канал оновлень",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Зміна каналу оновлень також вплине на сторінку керування застосунками. Так, після перемикання на канал \"бета\", вам пропонуватимуться до встановлення оновлення застосунків бета-версій на сторінці керування застосунками.",
    "Current update channel:" : "Поточний канал оновлень:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Ви завжди зможете перейти на нову версію, проте не можна буде повернутися на стабільну версію.",
    "Notify members of the following groups about available updates:" : "Повідомляти учасників таких груп про доступні оновлення:",
    "No groups" : "Без груп",
    "Only notifications for app updates are available." : "Доступні лише сповіщення про оновлення застосунків.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Вибраний канал оновлення робить спеціальні сповіщення для сервера застарілими.",
    "The selected update channel does not support updates of the server." : "Вибраний канал оновлення не підтримує оновлення сервера.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна нова версія: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Зауважте, що після нового випуску оновлення з’являється лише після першого другорядного випуску або пізніше. Ми розгортаємо нові версії з часом для наших користувачів і іноді пропускаємо версію, коли виявляються проблеми. Дізнайтеся більше про оновлення та канали випусків на {link}",
    "Checking apps for compatible versions" : "Перевірка застосунків на наявність сумісних версій",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Будь ласка, переконайтеся, що ваш config.php не встановлює для <samp>appstoreenabled</samp> значення false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Неможливо з'єднатися із App Store або оновлення не надійшли взагалі. Шукайте оновлення вручну або переконайтеся, що ваш сервер має доступ до Інтернету та може з'єднатися із App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Усі</strong> застосунки мають сумісну версію з цим випуском Nextcloud.",
    "Enterprise" : "Для бізнесу",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Для корпоративного використання. Завжди надає останній рівень виправлення, але не оновлюється до наступного основного випуску негайно. Це оновлення відбувається після того, як Nextcloud GmbH виконає додаткову надійність і тестування для широкомасштабних і критично важливих розгортань. Цей канал доступний лише для клієнтів і надає пакет Nextcloud Enterprise.",
    "Stable" : "Стабільний",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Остання стабільна версія. Він підходить для регулярного використання та завжди оновлюється до останньої основної версії.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Попередня версія лише для тестування нових функцій, а не для робочих середовищ.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> застосункок не сумісний з цією версією Nextcloud.","<strong>%n</strong> застосунки не сумісні з цією версією Nextcloud.","<strong>%n</strong> застосунків не сумісні з цією версією Nextcloud.","<strong>%n</strong> застосунків не сумісні з цією версією Nextcloud."],
    "Please use the command line updater to update." : "Для оновлення використовуйте оновлення за допомогою командного рядка.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Ви можете змінити канал оновлення, це вплине на сторінку керування програмами. Наприклад, після переходу на бета-канал оновлення вам буде запропоновано встановлення та оновлення до бета-версій застосунків на сторінці керування застосунків.",
    "Update channel:" : "Канал оновлення:",
    "Checked on {lastCheckedDate}" : "Перевірень {lastCheckedDate}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
